# gistrun

[![PyPI - Version](https://img.shields.io/pypi/v/gistrun.svg)](https://pypi.org/project/gistrun)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gistrun.svg)](https://pypi.org/project/gistrun)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install gistrun
```

## License

`gistrun` is distributed under the terms of the [GPL-3.0-or-later](https://spdx.org/licenses/GPL-3.0-or-later.html) license.
